#! /usr/bin/env python
import re
import sys

from scoundrels import barf


if sys.version_info[0] >= 3:
	xrange = range
	unicode = str
	basestring = str


class Clean:
	def __init__(self, debug):
		self.debug = debug
		self.chain_length = 2
		self.stop = '#$#'
	
	def sanitize(self, message):
		"""
		Sanitize the data. This is taken from Scrib 1.1.0 and could
		definitely use some tuning.
		"""
		if self.debug is 1:
			barf.Barf('DBG', 'Clean.sanitize: Sanitizing %s ' % message)
		things = [
			'://',
			'\"\'',
			"([a-zA-Z0-9\-_]+?\.)*[a-zA-Z0-9\-_]+?\.[a-zA-Z]{2,5}(\/[a-zA-Z0-9]*)*",
		]

		ret = message

		if self.debug is 1:
			barf.Barf('DBG', 'Clean.sanitize: Checking for newlines')
		for thing in things:
			ret = re.sub(thing, '', ret)
		
		ret = ret.replace("\n", " ")
		ret = ret.replace("\r", " ")

		if self.debug is 1:
			barf.Barf('DBG', 'Clean.sanitize: Scanning for color control codes...')
		# Strips out mIRC Control codes
		ccstrip = re.compile(
			"\x1f|\x02|\x12|\x0f|\x16|\x03(?:\d{1,2}(?:,\d{1,2})?)?",
			re.UNICODE
		)
		ret = ccstrip.sub("", ret)
		# Convert it all to ascii...
		try:
			ret = ret.encode('ascii', 'ignore')
		except:
			pass

		if self.debug is 1:
			barf.Barf('DBG', 'Clean.sanitize: Scanning for emoticons...')
		# Emotifacethings
		ret = ret.replace(": ", " : ")
		ret = ret.replace("; ", " ; ")
		# ^--- because some : and ; might be smileys...
		ret = ret.replace("`", "'")

		ret = ret.replace("?", " ? ")
		ret = ret.replace("!", " ! ")
		ret = ret.replace(".", " . ")
		ret = ret.replace(",", " , ")

		# Fixes broken emoticons...
		ret = ret.replace("^ . ^", "^.^")
		ret = ret.replace("- . -", "-.-")
		ret = ret.replace("O . o", "O.o")
		ret = ret.replace("o . O", "o.O")
		ret = ret.replace("o . o", "o.o")
		ret = ret.replace("O . O", "O.O")
		ret = ret.replace("< . <", "<.<")
		ret = ret.replace("> . >", ">.>")
		ret = ret.replace("> . <", ">.<")
		ret = ret.replace(": ?", ":?")
		ret = ret.replace(":- ?", ":-?")
		ret = ret.replace(", , l , ,", ",,l,,")
		ret = ret.replace("@ . @", "@.@")
		ret = ret.replace("D :", "D:")
		ret = ret.replace("c :", "c:")
		ret = ret.replace("C :", "C:")

		ret = ret.replace("||", "$C4")
		ret = ret.replace("|-:", "$b7")
		ret = ret.replace(":-|", "$b6")
		ret = ret.replace(";-|", "$b5")
		ret = ret.replace("|:", "$b4")
		ret = ret.replace(";|", "$b3")
		ret = ret.replace("=|", "$b2")
		ret = ret.replace(":|", "$b1")

		if ret is not None or ret is not 'None' or ret is not '':
			return self._unfilter(ret.strip())

	def _unfilter(self, message):
		"""
		Also taken from Scrib 1.1.0 and needs to be tuned.
		"""
		# Had to write my own initial capitalizing code *sigh*
		message = "%s%s" % (message[:1].upper(), message[1:])
		# Fixes punctuation
		message = message.replace(" ?", "?")
		message = message.replace(" !", "!")
		message = message.replace(" .", ".")
		message = message.replace(" ,", ",")
		message = message.replace(" : ", ": ")
		message = message.replace(" ; ", "; ")
		# Fixes I and I contractions
		message = message.replace(" i ", " I ")
		message = message.replace(" i'", " I'")

		message = message.replace("$C4", "||")
		message = message.replace("$b7", "|-:")
		message = message.replace("$b6", ";-|")
		message = message.replace("$b5", ":-|")
		message = message.replace("$b4", "|:")
		message = message.replace("$b3", ";|")
		message = message.replace("$b2", "=|")
		message = message.replace("$b1", ":|")

		return message

	def split(self, message):
		"""
		Split message into word list!
		"""
		words = message.split()

		if len(words) > self.chain_length:
			words.append(self.stop)
			for i in range(len(words) - self.chain_length):
				if self.debug is 1:
					barf.Barf('DBG', 'Clean.split: %s' % words[i:i + self.chain_length + 1])
				yield words[i:i + self.chain_length + 1]
