#! /usr/bin/env python
import random
import sys

from scoundrels import barf
from scrib import __appname__, cfg

try:
	import pymongo
except:
	barf.Barf('ERR', 'Please install pymongo module for python.')
	sys.exit()


defaultdbname = 'scrib'
defaulthost = 'localhost'
defaultport = 43957
defaultuser = 'public'
defaultpass = 'scrib'

settings = cfg.set('/.%s/%s' % (__appname__, 'scrib'))
settings.load('db', {
	'dbname': defaultdbname,
	'dbhost': defaulthost,
	'dbport': defaultport,
	'dbuser': defaultuser,
	'dbpass': defaultpass,
	'debug': 0
}, suppress=True)

try:
	client = pymongo.MongoClient(
		'mongodb://%s:%s@%s:%s/%s' % (
			settings.dbuser,
			settings.dbpass,
			settings.dbhost,
			settings.dbport,
			settings.dbname,
		)
	)
	db = client['%s' % settings.dbname]

except Exception as e:
	barf.Barf(
		'MSG',
		"Tried to connect to %s:%d" % (
			settings.dbhost,
			settings.dbport
		)
	)
	barf.Barf('ERR', e.message)
	sys.exit()


class Personality(object):
	"""
	Takes the personality information and turns
	them into class objects.
	"""
	def __init__(self, **entries):
		self.__dict__.update(entries)

	def insert(self):
		db.personality.insert(self.__dict__)


class Sentence(object):
	def __init__(self, **entries):
		self.__dict__.update(entries)

	def insert(self):
		db.sentence.insert(self.__dict__)


class Word(object):
	def __init__(self, **entries):
		self.__dict__.update(entries)

	def insert(self):
		db.word.insert(self.__dict__)

	def count(self):
		return 'I know %d words' % db.word.find({}).count()

	def get_random(self, key):
		if settings.debug is 1:
			barf.Barf('DBG', 'db.get_random:key=%s' % key)
		
		query = {"key": key}
		
		try:
			cursor = db.word.find(query).limit(50)
		except:
			barf.Barf('ERR', 'db.get_random: %s' % sys.exc_info()[0])
			return

		choices = []
		for doc in cursor:
			choices.append(doc)

		if settings.debug is 1:
			barf.Barf('DBG', 'db.get_random: number found: %d' % len(choices))

		if len(choices) is 0:
			return

		choice = random.choice(choices)

		return choice['key']
